@@ -52,7 +52,13 @@ class Deploy:
             _check_migrations_deploy(commits)
 
             message = "\n".join(
-                ["* " + c.commit.message.splitlines()[0] for c in commits]
+                [
+                    "* "
+                    + c.commit.message.splitlines()[0]
+                    + " by "
+                    + c.commit.author.name
+                    for c in commits
+                ]
             )
 
             logger.info(f"\nCommits list:\n{message}\n")
