@@ -13,6 +13,7 @@ from suite_py.lib.handler.github_handler import GithubHandler
 from suite_py.lib.handler.qainit_handler import QainitHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 from suite_py.lib.symbol import CHECKMARK, CROSSMARK
+from suite_py.commands.login import Login
 
 
 class MergePR:
@@ -27,6 +28,7 @@ class MergePR:
         self._qainit = QainitHandler(project, config, tokens)
 
     def run(self):
+        # pylint: disable=too-many-branches
         self._stop_if_master_locked()
 
         pr = self._select_pr()
@@ -81,12 +83,20 @@ class MergePR:
             )
             logger.info("Card updated")
 
+            if (
+                not self._qainit.user_info()
+                and self._config.user["delete_qa_after_merge"]
+            ):
+                logger.warning("You're not logged in.")
+                Login(self._config).run()
+
             if self._config.user["delete_qa_after_merge"]:
                 with Halo(
                     text="Searching for related QA environments...",
                     spinner="dots",
                     color="magenta",
                 ):
+
                     response = self._qainit.list(
                         {
                             "user": "all",
